#ifndef NT2_INCLUDE_FUNCTIONS_SCALAR_EXTRACT_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_SCALAR_EXTRACT_HPP_INCLUDED

#include <nt2/memory/include/functions/scalar/extract.hpp>

#endif
